@@ -32,7 +32,7 @@ QSqlDatabase DbAccess::database()
 {
     if (!QSqlDatabase::contains(QSqlDatabase::defaultConnection))
     {
-        QDir dataDir = QDir(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+        QDir dataDir = QDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
         if (!dataDir.exists())
         {
             dataDir.mkpath(dataDir.path());
@@ -409,3 +409,5 @@ bool DbAccess::migrateFrom1_0To1_1()
 
     return true;
 }
+
+#include "moc_dbaccess.cpp"
